#!/usr/bin/python

import sys
import unittest

from rnrclient import RatingsAndReviewsAPI
import piston_mini_client

class TestRnRClient(unittest.TestCase):

    def setUp(self):
        self.rnrclient = RatingsAndReviewsAPI()
        self.rnrclient.default_service_root = "http://testme/review/api/1.0"
        self.rnrclient._get = self._monkey_patched_get

    def _monkey_patched_get(self, url):
        self.hit_url = url
        return ("200 ok", "[]")

    def test_get_review(self):
        # simple case, just pkgname
        self.rnrclient.get_reviews(language="zh_CN", origin="ubuntu", 
                                   distroseries="lucid", packagename="foo")
        self.assertEqual(self.hit_url, "zh_CN/ubuntu/lucid/foo/page/1/")
        # pkgname with appname and space
        self.rnrclient.get_reviews(language="en", origin="ubuntu", 
                                   distroseries="lucid", packagename="foo",
                                   appname="Foo Bar")
        self.assertEqual(self.hit_url, "en/ubuntu/lucid/foo%3BFoo+Bar/page/1/")
        # complicated appname
        self.rnrclient.get_reviews(language="en", origin="ubuntu", 
                                   distroseries="lucid", packagename="foo",
                                   appname="Foo!;-+*;)")
        self.assertEqual(self.hit_url, 
                         "en/ubuntu/lucid/foo%3BFoo%21%3B-%2B%2A%3B%29/page/1/")
        # invalid pkgname
        kwargs = {"language" : "en", 
                  "origin" : "ubuntu",  
                  "distroseries" : "lucid", 
                  "packagename" : "foo;invalid" }
        self.assertRaises(piston_mini_client.validators.ValidationException,
                          self.rnrclient.get_reviews, kwargs)
        # invalid distroseries
        kwargs = {"language" : "en", 
                  "origin" : "ubuntu",
                  "distroseries" : "lucid;invalid-chars", 
                  "packagename" : "foo" }
        self.assertRaises(piston_mini_client.validators.ValidationException,
                          self.rnrclient.get_reviews, kwargs)
        # valid (but complicated) ppa origin
        kwargs = {"language" : "en", 
                  "origin" : "ppa:a.bono-wicked/ppa+fun-0.96,1",
                  "distroseries" : "lucid", 
                  "packagename" : "foo" }
        self.rnrclient.get_reviews(**kwargs)
        self.assertEqual(self.hit_url,
                         "en/ppa:a.bono-wicked/ppa+fun-0.96,1/lucid/foo/page/1/")

    def test_get_review_stats(self):
        self.rnrclient.review_stats()
        self.assertEqual(self.hit_url, "review-stats/")
        self.rnrclient.review_stats(days=4)
        self.assertEqual(self.hit_url, "review-stats/updates-last-7-days/")
        self.rnrclient.review_stats(days=14)
        self.assertEqual(self.hit_url, "review-stats/")
        self.rnrclient.review_stats(days=1)
        self.assertEqual(self.hit_url, "review-stats/updates-last-1-days/")
        self.rnrclient.review_stats(days=3)
        self.assertEqual(self.hit_url, "review-stats/updates-last-3-days/")
        self.rnrclient.review_stats(days=2)
        self.assertEqual(self.hit_url, "review-stats/updates-last-3-days/")


if __name__ == "__main__":
    unittest.main()
